@@ -26,5 +26,5 @@ public interface SearcherSource {
      * @throws IOException if the searcher can't be opened
      * @return A searcher object to be used by the caller.
      */
-    public Searcher getSearcher() throws IOException;
+    public Searcher getSearcher(int maxSearchers) throws IOException;
 }
